@@ -19,9 +19,10 @@
 #
 
 import preforkserver.events as pfe
+from preforkserver.poller import get_poller
 from time import sleep
-import select
 import socket
+import select
 import os
 
 __all__ = ['BaseChild']
@@ -56,10 +57,9 @@ class BaseChild(object):
         self._server_socket = server_socket
         self._max_requests = max_requests
         self._child_conn = child_conn
-        self._poll = select.poll()
-        self._poll_mask = select.POLLIN | select.POLLPRI
-        self._poll.register(self._server_socket.fileno(), self._poll_mask)
-        self._poll.register(self._child_conn.fileno(), self._poll_mask)
+        self._poll = get_poller(select.POLLIN | select.POLLPRI)
+        self._poll.register(self._server_socket)
+        self._poll.register(self._child_conn)
         self.protocol = protocol
         self.requests_handled = 0
         # The "conn" will be a socket connection object if this is a tcp 
@@ -89,7 +89,6 @@ class BaseChild(object):
             protocol = socket.SOCK_DGRAM
         s = socket.socket(socket.AF_INET , protocol)
         s.setsockopt(socket.SOL_SOCKET , socket.SO_REUSEPORT , 1)
-        s.settimeout(0.01)
         s.bind(addr)
         if protocol == socket.SOCK_STREAM:
             s.listen(manager.listen)
@@ -117,7 +116,11 @@ class BaseChild(object):
         """
         Handle an event sent from the parent
         """
-        event, msg = self._child_conn.recv()
+        try:
+            event, msg = self._child_conn.recv()
+        except EOFError:
+            self.closed = True
+            return
         event = int(event)
         if event & pfe.CLOSE:
             self.closed = True
@@ -157,19 +160,23 @@ class BaseChild(object):
         while True:
             events = []
             try:
-                events = self._poll.poll()
-            except select.error, e:
+                events = self._poll.poll(max_events=20)
+            except OSError:
+                pass
+            except IOError:
+                pass
+            except select.error:
                 # This happens when the system call is interrupted
                 pass
-            for fd, e in events:
-                if fd == self._server_socket.fileno():
+            for sock , e in events:
+                if sock == self._server_socket:
                     try:
                         self._handle_connection()
                     except Exception, e:
                         self._error(e)
                         self._shutdown(1)
                     self.requests_handled += 1
-                elif fd == self._child_conn.fileno():
+                elif sock == self._child_conn:
                     self._handle_parent_event()
             if self.closed:
                 self._shutdown()
@@ -178,8 +185,8 @@ class BaseChild(object):
                 self._shutdown()
 
     def _shutdown(self, status=0):
-        self._poll.unregister(self._child_conn.fileno())
-        self._poll.unregister(self._server_socket.fileno())
+        self._poll.unregister(self._child_conn)
+        self._poll.unregister(self._server_socket)
         self._child_conn.close()
         self._server_socket.close()
         self.shutdown()
@@ -189,6 +196,19 @@ class BaseChild(object):
     def run(self):
         self._loop()
 
+    def resp_to(self , msg):
+        """
+        This is a convenience function that will send the given msg string
+        to either the tcp client connection or to the current address in
+        the case of a UDP socket
+
+        msg:str         The message to respond to the client with
+        """
+        if self.protocol == 'tcp':
+            self.conn.sendall(msg)
+        else:
+            self._server_socket.sendto(msg , self.address)
+
     # Hooks to be overridden
     def pre_bind(self):
         """
@@ -213,7 +233,7 @@ class BaseChild(object):
 
     def post_accept(self):
         """
-        self.conn and self.addr are initialized here since a new connection
+        self.conn and self.address are initialized here since a new connection
         has been established.  You can make any modifications/setup needed 
         before handleRequest is called here.
         """
